==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/json.md <==
## JSON (.json)

### General Information

| Attribute       | Value                                             |
| --------------- | ------------------------------------------------- |
| Name            | Json                                              |
| snake_case_name | json                                              |
| Description     | JSON (.json)                                      |
| Extensions      | `.json`                                           |
| Read support    | No                                                |
| Write support   | Yes                                               |
| Single-file     | Yes                                               |
| Kind            | 📝 text                                            |
| Sort-on-write   | default_no                                        |
| Sort key        | (`headword_lower`)                                |
| Wiki            | [JSON](https://en.wikipedia.org/wiki/JSON)        |
| Website         | [www.json.org](https://www.json.org/json-en.html) |

### Write options

| Name        | Default | Type | Comment                                       |
| ----------- | ------- | ---- | --------------------------------------------- |
| encoding    | `utf-8` | str  | Encoding/charset                              |
| enable_info | `True`  | bool | Enable glossary info / metedata               |
| resources   | `True`  | bool | Enable resources / data files                 |
| word_title  | `False` | bool | add headwords title to begining of definition |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/json.md <==
## JSON (.json)

### General Information

| Attribute       | Value                                             |
| --------------- | ------------------------------------------------- |
| Name            | Json                                              |
| snake_case_name | json                                              |
| Description     | JSON (.json)                                      |
| Extensions      | `.json`                                           |
| Read support    | No                                                |
| Write support   | Yes                                               |
| Single-file     | Yes                                               |
| Kind            | 📝 text                                            |
| Sort-on-write   | No (by default)                                   |
| Sort key        | (`headword_lower`)                                |
| Wiki            | [JSON](https://en.wikipedia.org/wiki/JSON)        |
| Website         | [www.json.org](https://www.json.org/json-en.html) |

### Write options

| Name        | Default | Type | Comment                                        |
| ----------- | ------- | ---- | ---------------------------------------------- |
| encoding    | `utf-8` | str  | Encoding/charset                               |
| enable_info | `True`  | bool | Enable glossary info / metedata                |
| resources   | `True`  | bool | Enable resources / data files                  |
| word_title  | `False` | bool | add headwords title to beginning of definition |
